diff --git a/updater/install.c b/updater/install.c
index ff7de47..67f11bf 100644
--- a/updater/install.c
+++ b/updater/install.c
@@ -775,7 +775,11 @@ static int ApplyParsedPerms(
     int bad = 0;
 
     if (parsed.has_selabel) {
-        if (lsetfilecon(filename, parsed.selabel) != 0) {
+        if (lsetfilecon(filename, parsed.selabel) != 0
+#ifdef RECOVERY_CANT_USE_CONFIG_EXT4_FS_XATTR
+                 && (errno != EOPNOTSUPP)
+#endif
+           ) {
             uiPrintf(state, "ApplyParsedPerms: lsetfilecon of %s to %s failed: %s\n",
                     filename, parsed.selabel, strerror(errno));
             bad++;
@@ -829,7 +833,11 @@ static int ApplyParsedPerms(
 
     if (parsed.has_capabilities && S_ISREG(statptr->st_mode)) {
         if (parsed.capabilities == 0) {
-            if ((removexattr(filename, XATTR_NAME_CAPS) == -1) && (errno != ENODATA)) {
+            if ((removexattr(filename, XATTR_NAME_CAPS) == -1) && ((errno != ENODATA)
+#ifdef RECOVERY_CANT_USE_CONFIG_EXT4_FS_XATTR
+                 && (errno != EOPNOTSUPP)
+#endif
+               )) {
                 // Report failure unless it's ENODATA (attribute not set)
                 uiPrintf(state, "ApplyParsedPerms: removexattr of %s to %" PRIx64 " failed: %s\n",
                        filename, parsed.capabilities, strerror(errno));
@@ -843,7 +851,11 @@ static int ApplyParsedPerms(
             cap_data.data[0].inheritable = 0;
             cap_data.data[1].permitted = (uint32_t) (parsed.capabilities >> 32);
             cap_data.data[1].inheritable = 0;
-            if (setxattr(filename, XATTR_NAME_CAPS, &cap_data, sizeof(cap_data), 0) < 0) {
+            if (setxattr(filename, XATTR_NAME_CAPS, &cap_data, sizeof(cap_data), 0) < 0
+#ifdef RECOVERY_CANT_USE_CONFIG_EXT4_FS_XATTR
+                 && (errno != EOPNOTSUPP)
+#endif
+               ) {
                 uiPrintf(state, "ApplyParsedPerms: setcap of %s to %" PRIx64 " failed: %s\n",
                         filename, parsed.capabilities, strerror(errno));
                 bad++;
